@@ -125,9 +125,9 @@ class StudentGenerator:
 
         # Create name
         df["firstName"] = df["gender"].apply(
-            lambda x: names.get_firstName(gender=x)
+            lambda x: names.get_first_name(gender=x)
         )
-        df["lastName"] = [names.get_lastName() for x in range(self.n)]
+        df["lastName"] = [names.get_last_name() for x in range(self.n)]
 
         # Create email
         df["email"] = df[["firstName", "lastName"]].apply(
@@ -136,13 +136,13 @@ class StudentGenerator:
 
         # Create timestamp
         stop = self.start + pd.DateOffset(days=self.days)
-        df["created"] = [
+        df["createdAt"] = [
             randomtimestamp(start=self.start, end=stop) for x in range(self.n)
         ]
 
         # Reorder columns
         cols = [
-            "created",
+            "createdAt",
             "firstName",
             "lastName",
             "email",
@@ -168,7 +168,7 @@ class StudentGenerator:
                     data += [(group, k)] * count
 
             df[["group", response_var]] = pd.DataFrame(data)
-            df["in_experiment"] = True
+            df["inExperiment"] = True
 
         return df
 
